pilas.motores.motor_qt.BaseActor

Package pilas :: Package motores :: Module motor_qt :: Class BaseActor |
[hide private]
[frames] | no frames]

# Class BaseActor

source code

    object --+
             |
            BaseActor

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature | source code
definir_centro(self, x, y) | source code
obtener_posicion(self) | source code
definir_posicion(self, x, y) | source code
obtener_escala(self) | source code
definir_escala(self, s) | source code
definir_escala_x(self, s) | source code
definir_escala_y(self, s) | source code
definir_transparencia(self, nuevo_valor) | source code
obtener_transparencia(self) | source code
obtener_rotacion(self) | source code
definir_rotacion(self, r) | source code
set_espejado(self, espejado) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)